aboutsummaryrefslogtreecommitdiff
path: root/src/include/program_loading.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/program_loading.h')
-rw-r--r--src/include/program_loading.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/include/program_loading.h b/src/include/program_loading.h
index aa21cf57ab..e185b9271b 100644
--- a/src/include/program_loading.h
+++ b/src/include/program_loading.h
@@ -197,12 +197,15 @@ void payload_run(void);
void mirror_payload(struct prog *payload);
/*
* Set check_regions to true to check that the payload targets usable memory.
* With this flag set, if it does not, the load will fail and this function
* will return false. On successful payload loading this functions return true.
*
* Defined in src/lib/selfboot.c
*/
-bool selfload(struct prog *payload, bool check_regions);
+bool selfload_check(struct prog *payload);
+bool selfload(struct prog *payload);
#endif /* PROGRAM_LOADING_H */
@@ -197,12 +197,15 @@ void payload_run(void);
void mirror_payload(struct prog *payload);
/*
- * Set check_regions to true to check that the payload targets usable memory.
- * With this flag set, if it does not, the load will fail and this function
- * will return false. On successful payload loading this functions return true.
+ * selfload() and selfload_check() load payloads into memory.
+ * selfload() does not check the payload to see if it targets memory.
+ * Call selfload_check() to check that the payload targets usable memory.
+ * If it does not, the load will fail and this function
+ * will return false. On successful payload loading these functions return true.
*
* Defined in src/lib/selfboot.c